<?php
namespace Teknisa\PLA\Modules\Cardapio\Controllers;

use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use \Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Pla68000ExportacaoDeCardapioComListaSubstituicao extends \Teknisa\GER\Controllers\TeknisaCrud {

    private   $entityManager;
    protected $crudService;
    protected $dataSourceManager;
    protected $connection;
    protected $exportacaoService;

    public function __construct($crudService, Manager $dataSourceManager,$connection, $exportacaoService) {
        $this->crudService = $crudService;
        $this->dataSourceManager = $dataSourceManager;
        $this->connection = $connection;
        $this->exportacaoService = $exportacaoService;
	}
	
	public function exportaCardapio(DTO\Request $request, DTO\Response $response) {
		try {
			$row = $request->getRow();
			$conditions = array(
			    array(
				    "columnName" => "NRGRUPOSUBSCARD",
				    "operator" => "=",
				    "value" => $row['NRGRUPOSUBSCARD']
				)
			);
			
			$dataSet = $this->crudService->getFilteredDataSet("itgruposubscard", $conditions);
			$rowsServicos = $dataSet->getRows();
			
			foreach($rowsServicos as $filiserv) {
				if($row['CDFILIAL'] === $filiserv['CDFILIAL'] && $row['CDSERVFILI'] === $filiserv['CDSERVFILI']) {
					throw new \Exception('Serviço de origem pertence ao agrupamento selecionado para destino.');
				}
			}
			
			
			$NRLOGINTCARD = array();
			$retorno = array();
			foreach($rowsServicos as $servico) {
			   $row['CDFILDEST'] = $servico['CDFILIAL'];
			   $row['CDSERVDEST'] = $servico['CDSERVFILI'];
			   $nrLog = $this->executaExportacaoCardapio($row,$response);
			   $conditions = array(
         		    array(
        			    "columnName" => "NRLOGINTCARD",
        			    "operator" => "=",
        			    "value" => $nrLog
        			    ),
        			array(
        			    "columnName" => "CDFILDESTLOG",
        			    "operator" => "=",
        			    "value" => $row['CDFILDEST']
        			    )    
			    );
			    
			   $dataSet = $this->crudService->getFilteredDataSet("pla68000_nrlogintcard", $conditions);
			   $logs = $dataSet->getRows();	
			   if($nrLog) {
			   	  if(!empty($logs)) {
			   	  	array_push($retorno,$logs);
			   	  }
				  array_push($NRLOGINTCARD,$nrLog);
			   } 
			}
			$this->exportacaoService->deleteLog($NRLOGINTCARD);
			return $response->addDataSet(new DataSet("NRLOGINTCARD", $retorno));
			
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
	private function executaExportacaoCardapio($row, $response) {
		try {
			$procedure = new StoredProcedure($this->connection, 'EXPORTA_CARDAPIO_CONFIG');
			$procedure->addParam(new Param('P_CDFILIORIG',	Param::PARAM_INPUT, $row["CDFILIAL"],	Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_CDSERVORIG',	Param::PARAM_INPUT, $row['CDSERVFILI'],	Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_DTINIORIG',	Param::PARAM_INPUT, $row['DTINIORI'],	Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_DTFINORIG',	Param::PARAM_INPUT, $row['DTFINORIG'],	Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_CDFILIDEST',	Param::PARAM_INPUT, $row['CDFILDEST'],	Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_CDSERVDEST',	Param::PARAM_INPUT, $row['CDSERVDEST'],	Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_DTINIDEST',	Param::PARAM_INPUT, $row['DTINIDEST'],	Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_DTFINDEST',	Param::PARAM_INPUT, $row['DTFINDEST'],	Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_CONFIGORIG',	Param::PARAM_INPUT, "T",				Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_IDCOPCOMENS',	Param::PARAM_INPUT, "N",				Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_IDSOBREPOR',	Param::PARAM_INPUT, "S",				Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_CDOPERADOR',	Param::PARAM_INPUT, $row['CDOPERADOR'],	Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_MODOPROC',	Param::PARAM_INPUT, "M",				Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_IDGERASUBST', Param::PARAM_INPUT, "S",				Param::PARAM_TYPE_STR));
			return	$procedure->execute();
			
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
    	}
	}
}